@@ -35,6 +35,7 @@ class PressurePad(WBits):
     
 
     def when_pressure(self):
-        return Event(self.source_pressure, Event.TRIGGER_FALSE_TO_TRUE, val)
+        return Event(self.source_pressure, Event.TRIGGER_FALSE_TO_TRUE)
+
 
     
\ No newline at end of file
